package demo.config;

import javax.sql.DataSource;

import org.seasar.doma.jdbc.DomaAbstractConfig;
import org.seasar.doma.jdbc.JdbcLogger;
import org.seasar.doma.jdbc.RequiresNewController;
import org.seasar.doma.jdbc.dialect.Dialect;
import org.seasar.doma.jdbc.dialect.HsqldbDialect;
import org.seasar.extension.datasource.DataSourceFactory;
import org.seasar.extension.datasource.impl.SelectableDataSourceProxy;
import org.seasar.framework.container.annotation.tiger.Binding;
import org.seasar.framework.container.annotation.tiger.BindingType;

public class AppConfig extends DomaAbstractConfig {

    private JdbcLogger jdbcLogger = new CommonsLogger();

    private RequiresNewController requiresNewController = new S2RequiresNewController();

    private Dialect dialect = new HsqldbDialect();

    @Binding(bindingType = BindingType.MUST)
    private DataSource dataSource;

    @Binding(bindingType = BindingType.MAY)
    private DataSourceFactory dataSourceFactory;

    @Override
    public String getDataSourceName() {
        if (dataSourceFactory != null
                && dataSource instanceof SelectableDataSourceProxy) {
            return dataSourceFactory.getSelectableDataSourceName();
        }
        return super.getDataSourceName();
    }

    @Override
    public DataSource getDataSource() {
        return dataSource;
    }

    @Override
    public Dialect getDialect() {
        return dialect;
    }

    @Override
    public RequiresNewController getRequiresNewController() {
        return requiresNewController;
    }

    @Override
    public JdbcLogger getJdbcLogger() {
        return jdbcLogger;
    }

}
